@@ -11,7 +11,9 @@ from PIL import Image, ImageTk
 from ..resources.info import show_info
 from ..resources.language import Text
 from .dose_figure_handler import DoseFigureHandler
+from .nameandstyle import GraphNameAndStyle
 from .profile import ProfileHandler
+from .recent_files import RecentFileManager
 from .table import SimpleTable
 from .xrangeslider import XRangeSlider
 
@@ -123,13 +125,14 @@ class MainApplication(tk.Frame):
 
         self.DoseFigureHandler = DoseFigureHandler(self)
 
+        self.RecentFileManager = RecentFileManager(self)
+
         # Keybinding definitions
         self.parent.bind("<Configure>", self.handle_configure)
         self.parent.bind("<Control-e>", lambda type: self.load_file("egs"))
-        self.parent.bind("<Control-d>", lambda type: self.load_file("dp"))
+        self.parent.bind("<Control-m>", lambda type: self.load_file("measurement"))
         self.parent.bind("<Control-o>", lambda type: self.load_file("simulation"))
         self.parent.bind("<Control-s>", self.save_graph)
-        self.parent.bind("<Control-t>", lambda type: self.load_file("pdd"))
         self.parent.bind("<Control-p>", lambda type: self.load_file("ptw"))
         self.parent.bind("<Escape>", self.close_file)
         self.parent.bind("<Control-z>", self.remove_last_addition)
@@ -164,23 +167,18 @@ class MainApplication(tk.Frame):
         self.menubar = tk.Menu(self.parent, tearoff=False)
         self.filemenu = tk.Menu(self.menubar, tearoff=False)
         self.addmeasuremenu = tk.Menu(self.menubar, tearoff=False)
-        self.addmeasuremenu.add_command(
-            label=self.text.pdd[self.lang],
-            command=lambda: self.load_file("pdd"),
-            accelerator="Ctrl+T",
-        )
-        self.addmeasuremenu.add_command(
-            label=self.text.dp[self.lang],
-            command=lambda: self.load_file("dp"),
-            accelerator="Ctrl+D",
-        )
         self.addmeasuremenu.add_command(
             label=self.text.ptw[self.lang],
             command=lambda: self.load_file("ptw"),
             accelerator="Ctrl+P",
         )
+        self.addmeasuremenu.add_command(
+            label=self.text.measurement[self.lang],
+            command=lambda: self.load_file("measurement"),
+            accelerator="Ctrl+M",
+        )
 
-        self.addsimmenu = tk.Menu(self.menubar)
+        self.addsimmenu = tk.Menu(self.menubar, tearoff=False)
 
         self.addsimmenu.add_command(
             label="TOPAS",
@@ -197,6 +195,13 @@ class MainApplication(tk.Frame):
         self.filemenu.add_cascade(
             label=self.text.loadmeasurement[self.lang], menu=self.addmeasuremenu
         )
+
+        self.recentmenu = tk.Menu(self.menubar, tearoff=False)
+        self.filemenu.add_cascade(
+            label=self.text.recent[self.lang], menu=self.recentmenu
+        )
+        self.RecentFileManager.add_files_to_menu()
+
         self.filemenu.add_separator()
         self.filemenu.add_command(
             label=self.text.save[self.lang],
@@ -212,8 +217,8 @@ class MainApplication(tk.Frame):
         self.filemenu.add_command(
             label=self.text.end[self.lang], command=lambda: self.save_graph(True)
         )
-        self.filemenu.entryconfig(3, state=tk.DISABLED)
         self.filemenu.entryconfig(4, state=tk.DISABLED)
+        self.filemenu.entryconfig(5, state=tk.DISABLED)
         self.addmenu = tk.Menu(self.menubar, tearoff=False)
         self.addmenu.add_cascade(
             label=self.text.simulation[self.lang], menu=self.addsimmenu
@@ -227,7 +232,6 @@ class MainApplication(tk.Frame):
             command=self.remove_last_addition,
             accelerator="Ctrl+Z",
         )
-        self.addmenu.entryconfig(3, state=tk.DISABLED)
         self.menubar.add_cascade(label=self.text.file[self.lang], menu=self.filemenu)
         self.viewmenu = tk.Menu(self.menubar, tearoff=False)
         self.viewmenu.add_checkbutton(
@@ -324,6 +328,10 @@ class MainApplication(tk.Frame):
             label=self.text.resetcolors[self.lang], command=self.reset_colors
         )
 
+        self.normmenu.add_command(
+            label=self.text.resetmarkers[self.lang], command=self.reset_markers
+        )
+
         self.normmenu.add_separator()
 
         self.normalizemenu = tk.Menu(self.menubar, tearoff=False)
@@ -400,7 +408,7 @@ class MainApplication(tk.Frame):
             variable=self.diffplot,
         )
 
-        self.normmenu.entryconfig(12, state=tk.DISABLED)
+        self.normmenu.entryconfig(13, state=tk.DISABLED)
 
         self.errlimmenu = tk.Menu(self.menubar, tearoff=False)
         self.errlimmenu.add_command(
@@ -446,7 +454,7 @@ class MainApplication(tk.Frame):
         self.normmenu.add_cascade(
             label=Text().errlimmenu[self.lang], menu=self.errlimmenu
         )
-        self.normmenu.entryconfig(13, state=tk.DISABLED)
+        self.normmenu.entryconfig(14, state=tk.DISABLED)
 
         self.menubar.add_command(label=self.text.about[self.lang], command=self.about)
 
@@ -632,7 +640,7 @@ class MainApplication(tk.Frame):
             filetypes = [(self.text.topas[self.lang], [".csv", ".bin"])]
         if type == "egs":
             filetypes = [(self.text.egs[self.lang], [".3ddose"])]
-        elif type == "pdd" or type == "dp":
+        elif type == "measurement":
             filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
         elif type == "ptw":
             filetypes = [(self.text.ptw[self.lang], ".mcc")]
@@ -644,15 +652,16 @@ class MainApplication(tk.Frame):
             return
 
         for file in self.current_file:
+            self.RecentFileManager.add_file((file, type))
+            self.RecentFileManager.add_files_to_menu()
             self.filenames += [(file, type)]
-        self.logocanvas.pack_forget()
         self.show_preview()
         self.filemenu.entryconfig(0, state=tk.DISABLED)
         self.filemenu.entryconfig(1, state=tk.DISABLED)
-        self.filemenu.entryconfig(3, state=tk.NORMAL)
         self.filemenu.entryconfig(4, state=tk.NORMAL)
+        self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
-            self.normmenu.entryconfig(12, state=tk.DISABLED)
+            self.normmenu.entryconfig(13, state=tk.DISABLED)
         self.saved = False
 
         return
@@ -679,30 +688,40 @@ class MainApplication(tk.Frame):
             "3ddose": "egs",
             "bin": "simulation",
             "mcc": "ptw",
+            "txt": "measurement",
         }
         extensions = []
         for i, file in enumerate(files):
             try:
-                extensions += [types[file.split(".")[-1]]]
+                if file.split(".")[-1] == "csv":
+                    with open(file) as testfile:
+                        content = testfile.readlines()[0]
+                        if "TOPAS" in content:
+                            extensions += ["simulation"]
+                        else:
+                            extensions += ["measurement"]
+                else:
+                    extensions += [types[file.split(".")[-1]]]
             except KeyError:
                 files.pop(i)
 
         self.current_file = files
 
         for i, file in enumerate(self.current_file):
+            self.RecentFileManager.add_file((file, extensions[i]))
+            self.RecentFileManager.add_files_to_menu()
             self.filenames += [(file, extensions[i])]
 
         if len(self.filenames) == 0:
             return
 
-        self.logocanvas.pack_forget()
         self.show_preview()
         self.filemenu.entryconfig(0, state=tk.DISABLED)
         self.filemenu.entryconfig(1, state=tk.DISABLED)
-        self.filemenu.entryconfig(3, state=tk.NORMAL)
         self.filemenu.entryconfig(4, state=tk.NORMAL)
+        self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
-            self.normmenu.entryconfig(12, state=tk.DISABLED)
+            self.normmenu.entryconfig(13, state=tk.DISABLED)
         self.saved = False
 
     def close_file(self, event=None):
@@ -712,14 +731,12 @@ class MainApplication(tk.Frame):
         self.canvas.pack_forget()
         self.filemenu.entryconfig(0, state=tk.NORMAL)
         self.filemenu.entryconfig(1, state=tk.NORMAL)
-        self.filemenu.entryconfig(3, state=tk.DISABLED)
         self.filemenu.entryconfig(4, state=tk.DISABLED)
-        self.addmenu.entryconfig(0, state=tk.NORMAL)
-        self.addmenu.entryconfig(1, state=tk.NORMAL)
+        self.filemenu.entryconfig(5, state=tk.DISABLED)
         self.addmeasuremenu.entryconfig(0, state=tk.NORMAL)
         self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
-        self.normmenu.entryconfig(12, state=tk.DISABLED)
         self.normmenu.entryconfig(13, state=tk.DISABLED)
+        self.normmenu.entryconfig(14, state=tk.DISABLED)
         self.parammenu.entryconfig(0, state=tk.NORMAL)
         self.menubar.delete(4, 5)
         self.filenames = []
@@ -772,6 +789,12 @@ class MainApplication(tk.Frame):
             pass
 
         if exit == True:
+            self.profile.set_attribute("state", self.parent.state())
+            if self.parent.state() == "zoomed":
+                self.profile.set_attribute("geometry", " ")
+            else:
+                self.profile.set_attribute("geometry", self.parent.geometry())
+
             if self.saved == False:
 
                 prompt = sd.messagebox.askyesno("", self.text.closeprompt[self.lang])
@@ -873,7 +896,7 @@ class MainApplication(tk.Frame):
         if len(self.filenames) == 2:
             self.diffplot.set(False)
             self.DoseFigureHandler.diffplot = False
-            self.normmenu.entryconfig(12, state=tk.DISABLED)
+            self.normmenu.entryconfig(13, state=tk.DISABLED)
 
         if self.filenames[-1][0].endswith(".mcc") == True:
             self.filenames.pop(-1)
@@ -885,8 +908,6 @@ class MainApplication(tk.Frame):
             self.DoseFigureHandler.plots.pop(-1)
 
         if len(self.filenames) <= 4:
-            self.addmenu.entryconfig(0, state=tk.NORMAL)
-            self.addmenu.entryconfig(1, state=tk.NORMAL)
             self.parammenu.entryconfig(0, state=tk.NORMAL)
 
         self.canvas.itemconfig(self.image_on_canvas, image=None)
@@ -914,9 +935,9 @@ class MainApplication(tk.Frame):
 
         self.DoseFigureHandler.diffplot = self.diffplot.get()
         if self.diffplot.get() == True:
-            self.normmenu.entryconfig(13, state=tk.NORMAL)
+            self.normmenu.entryconfig(14, state=tk.NORMAL)
         else:
-            self.normmenu.entryconfig(13, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
 
         self.refresh()
 
@@ -1016,14 +1037,24 @@ class MainApplication(tk.Frame):
         self.DoseFigureHandler.colors = self.profile.get_attribute("default_colors")
         self.show_preview()
 
+    def reset_markers(self):
+        self.profile.set_attribute(
+            "markers", self.profile.get_attribute("default_markers")
+        )
+        self.DoseFigureHandler.colors = self.profile.get_attribute("default_markers")
+        self.show_preview()
+
     def show_preview(self):
 
         """
         Invokes DoseFigureHandler to create and display the graphs with the selected options
         """
+        # try:
         self.photoimage, self.direction = self.DoseFigureHandler.return_figure(
             self.filenames
         )
+        # except Exception:
+        #    return
 
         self.logocanvas.pack_forget()
         if self.tablevar.get() == True:
@@ -1049,26 +1080,22 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Down>", lambda boolean: self.change_order(False))
 
         if len(self.DoseFigureHandler.plots) >= 2:
-            self.addmenu.entryconfig(3, state=tk.NORMAL)
-            self.normmenu.entryconfig(12, state=tk.DISABLED)
+            self.normmenu.entryconfig(14, state=tk.DISABLED)
 
         if len(self.DoseFigureHandler.plots) == 2:
-            self.normmenu.entryconfig(12, state=tk.NORMAL)
+            self.normmenu.entryconfig(14, state=tk.NORMAL)
 
         if len(self.DoseFigureHandler.plots) > 5:
             self.parammenu.entryconfig(0, state=tk.DISABLED)
 
-        if len(self.DoseFigureHandler.plots) == 10:
-            self.addmenu.entryconfig(0, state=tk.DISABLED)
-            self.addmenu.entryconfig(1, state=tk.DISABLED)
         if self.direction == "Z":
             self.addmeasuremenu.entryconfig(1, state=tk.DISABLED)
-            self.normmenu.entryconfig(7, state=tk.DISABLED)
-            self.normmenu.entryconfig(10, state=tk.DISABLED)
+            self.normmenu.entryconfig(8, state=tk.DISABLED)
+            self.normmenu.entryconfig(11, state=tk.DISABLED)
         else:
             self.addmeasuremenu.entryconfig(0, state=tk.DISABLED)
-            self.normmenu.entryconfig(7, state=tk.NORMAL)
-            self.normmenu.entryconfig(10, state=tk.NORMAL)
+            self.normmenu.entryconfig(8, state=tk.NORMAL)
+            self.normmenu.entryconfig(11, state=tk.NORMAL)
 
         if self.menuflag == False:
             self.menubar.add_cascade(label=self.text.add[self.lang], menu=self.addmenu)
@@ -1201,8 +1228,7 @@ class MainApplication(tk.Frame):
 
                 self.table.pack(side="bottom", fill="both", padx=(2, 2), pady=(10, 2))
             self.table.configure(bg="black")
-        except Exception as e:
-            print(e)
+        except Exception:
             self.tablevar.set(False)
             sd.messagebox.showwarning("", self.text.calcfail[self.lang])
 
@@ -1295,6 +1321,10 @@ class MainApplication(tk.Frame):
         according to the window size and name length
         """
 
+        state = self.profile.get_attribute("state")
+        if state != self.parent.state():
+            self.profile.set_attribute("state", self.parent.state())
+            self.starttime -= 0.1
         if type(event.widget) == tk.Label:
 
             return
@@ -1395,10 +1425,16 @@ class MainApplication(tk.Frame):
                                 )
                             )
                         ),
-                        (coords[1] - imdims[1] * (0.478 - i * 0.035 + normdiff))
+                        (
+                            (canvdims[1] - imdims[1]) // 2
+                            + imdims[1] * (0.01 + i * 0.035 + normdiff)
+                        )
                         * factor,
                         coords[0] + imdims[0] * 0.49,
-                        (coords[1] - imdims[1] * (0.443 - i * 0.035 + normdiff))
+                        (
+                            (canvdims[1] - imdims[1]) // 2
+                            + imdims[1] * (0.06 + i * 0.035 + normdiff)
+                        )
                         * factor,
                         fill="",
                         outline="",
@@ -1496,23 +1532,16 @@ class MainApplication(tk.Frame):
                             if self.xlimmenu == False:
                                 self.change_xrange()
                             else:
-                                newname = sd.askstring(
-                                    "",
-                                    self.text.changefilename[self.lang],
-                                    initialvalue=self.DoseFigureHandler.xlabel,
-                                )
-                                if newname != None:
-                                    self.DoseFigureHandler.xaxisname = newname
-                                    self.show_preview()
+                                dialog = GraphNameAndStyle(self, "X")
+                                self.parent.wait_window(dialog.top)
+
+                                self.show_preview()
                             return
-                        newname = sd.askstring(
-                            "",
-                            self.text.changefilename[self.lang],
-                            initialvalue=self.DoseFigureHandler.plots[index].filename,
-                        )
-                        if newname != None:
-                            self.DoseFigureHandler.plots[index].filename = newname
-                            self.show_preview()
+
+                        dialog = GraphNameAndStyle(self, index)
+                        self.parent.wait_window(dialog.top)
+
+                        self.show_preview()
 
     def check_right_click(self, e):
 
